==> qgis-plugin-dev-tools-0.1.0.tar.gz: qgis-plugin-dev-tools-0.1.0/test/test_read_pyproject.py <==
from pathlib import Path
from typing import List

import pytest

from qgis_plugin_dev_tools.config.pyproject import read_pyproject_config


@pytest.fixture()
def create_pyproject_toml_with_contents(tmpdir):
    toml_file_path = Path(tmpdir) / "test.toml"

    def write_contents_from_list(contents: List[str]):
        toml_file_path.write_text("\n".join(contents))
        return toml_file_path

    return write_contents_from_list


def test_section_missing_fails(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.not_the_expected_name]",
            'plugin_package_name = "testing"',
        ]
    )

    with pytest.raises(ValueError):
        read_pyproject_config(test_file)


def test_package_name_missing_fails(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'not_the_package_name_key = "testing"',
        ]
    )

    with pytest.raises(ValueError):
        read_pyproject_config(test_file)


def test_requires_allowed_missing(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
        ]
    )

    assert read_pyproject_config(test_file).runtime_requires == []


def test_requires_allowed_empty(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
            "runtime_requires = []",
        ]
    )

    assert read_pyproject_config(test_file).runtime_requires == []


def test_section_read_to_dataclass(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
            'runtime_requires = ["one", "another"]',
        ]
    )

    result = read_pyproject_config(test_file)

    assert result.plugin_package_name == "testing"
    assert result.runtime_requires == ["one", "another"]

==> qgis-plugin-dev-tools-0.1.2.tar.gz: qgis-plugin-dev-tools-0.1.2/test/test_read_pyproject.py <==
from pathlib import Path
from typing import List

import pytest

from qgis_plugin_dev_tools.config.pyproject import read_pyproject_config


@pytest.fixture()
def create_pyproject_toml_with_contents(tmpdir):
    toml_file_path = Path(tmpdir) / "test.toml"

    def write_contents_from_list(contents: List[str]):
        toml_file_path.write_text("\n".join(contents), encoding="utf-8")
        return toml_file_path

    return write_contents_from_list


def test_section_missing_fails(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.not_the_expected_name]",
            'plugin_package_name = "testing"',
        ]
    )

    with pytest.raises(ValueError):
        read_pyproject_config(test_file)


def test_package_name_missing_fails(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'not_the_package_name_key = "testing"',
        ]
    )

    with pytest.raises(ValueError):
        read_pyproject_config(test_file)


def test_requires_allowed_missing(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
        ]
    )

    assert read_pyproject_config(test_file).runtime_requires == []


def test_requires_allowed_empty(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
            "runtime_requires = []",
        ]
    )

    assert read_pyproject_config(test_file).runtime_requires == []


def test_section_read_to_dataclass(create_pyproject_toml_with_contents):
    test_file = create_pyproject_toml_with_contents(
        [
            "[tool.qgis_plugin_dev_tools]",
            'plugin_package_name = "testing"',
            'runtime_requires = ["one", "another"]',
        ]
    )

    result = read_pyproject_config(test_file)

    assert result.plugin_package_name == "testing"
    assert result.runtime_requires == ["one", "another"]
